==> fuel-ui-0.4.1-3.tgz: package/esm/pipes/pipes.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { FuiFormatPipeModule } from "./format/format";
import { FuiMapToIterablePipeModule } from "./mapToIterable/mapToIterable";
import { FuiOrderByPipeModule } from "./orderBy/orderBy";
import { FuiRangePipeModule } from "./range/range";
export * from "./format/format";
export * from "./mapToIterable/mapToIterable";
export * from "./orderBy/orderBy";
export * from "./range/range";
const pipeModules = [
    FuiFormatPipeModule,
    FuiMapToIterablePipeModule,
    FuiOrderByPipeModule,
    FuiRangePipeModule
];
export let FuiPipesModule = class FuiPipesModule {
};
FuiPipesModule = __decorate([
    NgModule({
        imports: pipeModules,
        exports: pipeModules
    }), 
    __metadata('design:paramtypes', [])
], FuiPipesModule);

==> fuel-ui-0.4.1-4.tgz: package/esm/pipes/pipes.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { FuiFormatPipeModule } from "./Format/Format";
import { FuiMapToIterablePipeModule } from "./MapToIterable/MapToIterable";
import { FuiOrderByPipeModule } from "./OrderBy/OrderBy";
import { FuiRangePipeModule } from "./Range/Range";
export * from "./Format/Format";
export * from "./MapToIterable/MapToIterable";
export * from "./OrderBy/OrderBy";
export * from "./Range/Range";
const pipeModules = [
    FuiFormatPipeModule,
    FuiMapToIterablePipeModule,
    FuiOrderByPipeModule,
    FuiRangePipeModule
];
export let FuiPipesModule = class FuiPipesModule {
};
FuiPipesModule = __decorate([
    NgModule({
        imports: pipeModules,
        exports: pipeModules
    }), 
    __metadata('design:paramtypes', [])
], FuiPipesModule);
